@@ -1,5 +1,5 @@
 """
-Copyright (c) 2012, Dominik Schacht
+Copyright (c) 2013, Dominik Schacht
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification,
@@ -132,8 +132,6 @@ class EntityManager(object):
         """ Create an entity of the specified type. """
         # Create an entity and add a copy of every component specified in the prototype.
         entity = Entity()
-        # TODO: Remove logging
-        print "Created entity of type '{}'.".format(type_name)
         entity.components = [copy.copy(comp) for comp in self.types[type_name]]
         entity.components.append(TypeComponent(type_name))
         return self.add_entity(entity)
@@ -309,6 +307,9 @@ class Processor(object):
         try:
             if self.component_types is not None and type(self.component_types) is not set:
                 self.component_types = set(self.component_types)
+        except TypeError:
+            # Handle the exception when component_types is not a proper collection but a single object
+            self.component_types = set((self.component_types,))
         except AttributeError:
             self.component_types = set()
 
