@@ -71,7 +71,7 @@ class TestQuidditas(TestCase):
         self.q.component_manager.add_components.is_called_once()
 
     def test_add_entity_by_type(self):
-        """ DOCME """
+        """ Test assembling an entity by a type name. """
         comp = TestingComponentA()
         entity = Mock()
         entity.components = (comp,)
@@ -93,7 +93,8 @@ class TestQuidditas(TestCase):
         self.q.processor_manager.update.assert_called_once_with(1)
 
     def test_add_remove_processor(self):
-        """ DOCME """
+        """ Test adding and removing a processor instance and if this
+        processor receives proper calls from quidditas. """
         proc = TestingProcessorA()
         proc.refresh_entities = MagicMock()
         self.q.processor_manager.add_processor.return_value = True
@@ -107,13 +108,16 @@ class TestQuidditas(TestCase):
         proc.refresh_entities.assert_called_once_with(entity_list)
 
     def test_remove_processor(self):
-        """ DOCME """
+        """ Test if processors can be removed from the processor manager
+        via quidditas. """
         proc = TestingProcessorA()
         self.q.remove_processor(proc)
         self.q.processor_manager.remove_processor.called_once_with(proc)
 
     def test_remove_entity_gid(self):
-        """ DOCME """
+        """ Test if a single entity can be removed by its gid and that
+        the managers are notified of that change on the next update (and
+        not before). """
         e = quidditas.Entity()
         self.q.remove_entity_gid(e.gid)
 
@@ -128,7 +132,8 @@ class TestQuidditas(TestCase):
         self.q.processor_manager.refresh_entities_gid.assert_called_once()
 
     def test_add_component(self):
-        """ DOCME """
+        """ Test if components can be added to an entity after its
+        creation. """
         entity = quidditas.Entity()
         comp = TestingComponentA()
         self.q.add_component(entity, comp)
@@ -136,7 +141,7 @@ class TestQuidditas(TestCase):
         self.q.processor_manager.refresh_entity.assert_called_once_with(entity)
 
     def test_remove_component(self):
-        """ DOCME """
+        """ Test removing components via quidditas. """
         entity = quidditas.Entity()
         comp = TestingComponentA()
         self.q.remove_component(entity, comp)
@@ -187,7 +192,8 @@ class TestEntity(TestCase):
         self.q.remove_component.assert_called_once_with(self.e, compA)
 
     def test_get_component_without_quidditas(self):
-        """ DOCME """
+        """ Test if components can be retrieved when an entity is not yet
+        associated with a quidditas instance. """
         comp = TestingComponentA()
         self.e.remove_component(comp) #Nothing happens
 
@@ -200,7 +206,8 @@ class TestEntity(TestCase):
         assert self.e.get_component(TestingComponentB) is None
 
     def test_get_component_with_quidditas(self):
-        """ DOCME """
+        """ Test if components can be retrieved when an entity
+        is associated with a quidditas instance. """
         comp = TestingComponentA()
         self.q = quidditas.Quidditas()
         self.q.add_entity(self.e)
